@@ -1,5 +1,5 @@
-/* GnomENIUS Calculator
- * Copyright (C) 1997, 1998 the Free Software Foundation.
+/* GENIUS Calculator
+ * Copyright (C) 1997-2005 George Lebl
  *
  * Author: George Lebl
  *
@@ -19,14 +19,29 @@
  * USA.
  */
 
-#ifndef _FUNCLIB_H_
-#define _FUNCLIB_H_
-
-#include "eval.h"
+#ifndef FUNCLIB_H_
+#define FUNCLIB_H_
 
 /*add the routines to the dictionary*/
-void funclib_addall(void);
+void gel_funclib_addall(void);
 /*remove all cached floating point values*/
-void break_fp_caches(void);
+void gel_break_fp_caches(void);
 
-#endif
+GelETree * gel_apply_func_to_matrix (GelCtx *ctx,
+				     GelETree *mat, 
+				     GelBIFunction function,
+				     const char *ident, 
+				     gboolean *exception);
+GelETree * gel_apply_func_to_matrixen (GelCtx *ctx,
+				       GelETree *mat1,
+				       GelETree *mat2,
+				       GelBIFunction function,
+				       const char *ident,
+				       gboolean *exception);
+
+int gel_get_nonnegative_integer (mpw_ptr z, const char *funcname);
+
+int gel_count_arguments (GelETree **a);
+
+
+#endif /* FUNCLIB_H_ */
